@@ -11,7 +11,7 @@ class Atlas : public Map
 	Q_OBJECT
 
 public:
-	Atlas(const QString &path, QObject *parent = 0);
+	Atlas(const QString &fileName, QObject *parent = 0);
 	~Atlas();
 
 	const QString &name() const {return _name;}
@@ -20,31 +20,37 @@ public:
 	qreal resolution(const QPointF &p) const;
 
 	qreal zoom() const;
-	qreal zoomFit(const QSize &size, const QRectF &br);
+	qreal zoomFit(const QSize &size, const RectC &br);
+	qreal zoomFit(qreal resolution, const Coordinates &c);
 	qreal zoomIn();
 	qreal zoomOut();
 
-	QPointF ll2xy(const Coordinates &c) const;
-	Coordinates xy2ll(const QPointF &p) const;
+	QPointF ll2xy(const Coordinates &c);
+	Coordinates xy2ll(const QPointF &p);
 
 	void draw(QPainter *painter, const QRectF &rect);
 
-	bool isValid() {return _valid;}
+	void unload();
+
+	bool isValid() const {return _valid;}
+	const QString &errorString() const {return _errorString;}
 
 private:
 	void draw(QPainter *painter, const QRectF &rect, int mapIndex);
-	bool isAtlas(const QFileInfoList &files);
+	bool isAtlas(Tar &tar, const QString &path);
 	void computeZooms();
 	void computeBounds();
 
 	QString _name;
 	bool _valid;
+	QString _errorString;
 
-	Tar _tar;
 	QList<OfflineMap*> _maps;
 	QVector<QPair<int, int> > _zooms;
 	QVector<QPair<QRectF, QRectF> > _bounds;
 	int _zoom;
+
+	int _ci, _cz;
 };
 
 #endif // ATLAS_H
