@@ -1,10 +1,10 @@
 #include "data.h"
+#include "cadencegraphitem.h"
 #include "cadencegraph.h"
 
 
 CadenceGraph::CadenceGraph(QWidget *parent) : GraphTab(parent)
 {
-	_units = Metric;
 	_showTracks = true;
 
 	GraphView::setYUnits(tr("1/min"));
@@ -28,21 +28,16 @@ void CadenceGraph::loadData(const Data &data, const QList<PathItem *> &paths)
 {
 	for (int i = 0; i < data.tracks().count(); i++) {
 		const Graph &graph = data.tracks().at(i)->cadence();
-		qreal sum = 0, w = 0;
 
 		if (graph.size() < 2) {
 			skipColor();
 			continue;
 		}
 
-		for (int j = 1; j < graph.size(); j++) {
-			qreal ds = graph.at(j).s() - graph.at(j-1).s();
-			sum += graph.at(j).y() * ds;
-			w += ds;
-		}
-		_avg.append(QPointF(data.tracks().at(i)->distance(), sum/w));
+		CadenceGraphItem *gi = new CadenceGraphItem(graph, _graphType);
+		GraphView::addGraph(gi, paths.at(i));
 
-		GraphView::loadGraph(graph, paths.at(i));
+		_avg.append(QPointF(data.tracks().at(i)->distance(), gi->avg()));
 	}
 
 	for (int i = 0; i < data.routes().count(); i++)
