@@ -53,13 +53,16 @@ bool Downloader::doDownload(const Download &dl, const Redirect &redirect)
 		request.setAttribute(ATTR_LEVEL, QVariant(redirect.level()));
 	}
 #ifdef Q_WS_MAEMO_5
-	if (url.toString().startsWith("https://"))
-	{
+	//if (url.toString().startsWith("https://"))
+	//{
+		//qDebug() << QSslConfiguration::supportedCiphers;
+		//QSslConfiguration configSsl = request.sslConfiguration();
 		QSslConfiguration configSsl = QSslConfiguration::defaultConfiguration();
-		configSsl.setProtocol(QSsl::AnyProtocol);
-		//configSsl.setProtocol(QSsl::TlsV1);
+		//configSsl.setProtocol(QSsl::AnyProtocol);
+		configSsl.setProtocol(QSsl::TlsV1);
+		QSslConfiguration::setDefaultConfiguration(configSsl);
 		request.setSslConfiguration(configSsl);
-	}
+	//}
 #endif
 	request.setRawHeader("User-Agent", USER_AGENT);
 	QNetworkReply *reply = _manager.get(request);
@@ -73,7 +76,7 @@ bool Downloader::saveToDisk(const QString &filename, QIODevice *data)
 	QFile file(filename);
 
 	if (!file.open(QIODevice::WriteOnly)) {
-		fprintf(stderr, "Error writing map tile: %s: %s\n",
+		qWarning("Error writing map tile: %s: %s\n",
 		  qPrintable(filename), qPrintable(file.errorString()));
 		return false;
 	}
@@ -92,11 +95,11 @@ void Downloader::downloadFinished(QNetworkReply *reply)
 		QUrl origin = reply->request().attribute(ATTR_ORIGIN).toUrl();
 		if (origin.isEmpty()) {
 			_errorDownloads.insert(url);
-			fprintf(stderr, "Error downloading map tile: %s: %s\n",
+			qWarning("Error downloading map tile: %s: %s\n",
 			  url.toEncoded().constData(), qPrintable(reply->errorString()));
 		} else {
 			_errorDownloads.insert(origin);
-			fprintf(stderr, "Error downloading map tile: %s -> %s: %s\n",
+			qWarning("Error downloading map tile: %s -> %s: %s\n",
 			  origin.toEncoded().constData(), url.toEncoded().constData(),
 			  qPrintable(reply->errorString()));
 		}
@@ -111,11 +114,11 @@ void Downloader::downloadFinished(QNetworkReply *reply)
 
 			if (location == url) {
 				_errorDownloads.insert(url);
-				fprintf(stderr, "Error downloading map tile: %s: "
+				qWarning("Error downloading map tile: %s: "
 				  "redirect loop\n", url.toEncoded().constData());
 			} else if (level >= MAX_REDIRECT_LEVEL) {
 				_errorDownloads.insert(origin);
-				fprintf(stderr, "Error downloading map tile: %s: "
+				qWarning("Error downloading map tile: %s: "
 				  "redirect level limit reached\n",
 				  origin.toEncoded().constData());
 			} else {
