@@ -70,7 +70,7 @@ qreal EmptyMap::zoomOut()
 
 void EmptyMap::draw(QPainter *painter, const QRectF &rect)
 {
-	painter->fillRect(rect, Qt::white);
+	painter->fillRect(rect, _backgroundColor);
 }
 
 QPointF EmptyMap::ll2xy(const Coordinates &c)
