@@ -26,15 +26,28 @@ ExportDialog::ExportDialog(Export *exp, QWidget *parent)
 	_fileSelect->setFile(_export->fileName);
 
 	_paperSize = new QComboBox();
+	_paperSize->addItem("A2", QPrinter::A2);
 	_paperSize->addItem("A3", QPrinter::A3);
 	_paperSize->addItem("A4", QPrinter::A4);
 	_paperSize->addItem("A5", QPrinter::A5);
+	_paperSize->addItem("A6", QPrinter::A6);
+	_paperSize->addItem("B3", QPrinter::B3);
+	_paperSize->addItem("B4", QPrinter::B4);
+	_paperSize->addItem("B5", QPrinter::B5);
+	_paperSize->addItem("B6", QPrinter::B6);
 	_paperSize->addItem("Tabloid", QPrinter::Tabloid);
 	_paperSize->addItem("Legal", QPrinter::Legal);
 	_paperSize->addItem("Letter", QPrinter::Letter);
 	if ((index = _paperSize->findData(_export->paperSize)) >= 0)
 		_paperSize->setCurrentIndex(index);
 
+	_resolution = new QComboBox();
+	_resolution->addItem("300 DPI", 300);
+	_resolution->addItem("600 DPI", 600);
+	_resolution->addItem("1200 DPI", 1200);
+	if ((index = _resolution->findData(_export->resolution)) >= 0)
+		_resolution->setCurrentIndex(index);
+
 	_portrait = new QRadioButton(tr("Portrait"));
 	_landscape = new QRadioButton(tr("Landscape"));
 	QHBoxLayout *orientationLayout = new QHBoxLayout();
@@ -81,6 +94,7 @@ ExportDialog::ExportDialog(Export *exp, QWidget *parent)
 #endif // Q_OS_MAC
 	QFormLayout *pageSetupLayout = new QFormLayout;
 	pageSetupLayout->addRow(tr("Page size:"), _paperSize);
+	pageSetupLayout->addRow(tr("Resolution:"), _resolution);
 	pageSetupLayout->addRow(tr("Orientation:"), orientationLayout);
 	pageSetupLayout->addRow(tr("Margins:"), marginsLayout);
 #ifdef Q_OS_MAC
@@ -161,9 +175,11 @@ void ExportDialog::accept()
 	  ? QPrinter::Portrait : QPrinter::Landscape;
 	QPrinter::PaperSize paperSize = static_cast<QPrinter::PaperSize>
 	  (_paperSize->itemData(_paperSize->currentIndex()).toInt());
+	int resolution = _resolution->itemData(_resolution->currentIndex()).toInt();
 
 	_export->fileName = _fileSelect->file();
 	_export->paperSize = paperSize;
+	_export->resolution = resolution;
 	_export->orientation = orientation;
 	if (_export->units == Imperial)
 		_export->margins = MarginsF(_leftMargin->value() / MM2IN,
