@@ -6,37 +6,37 @@
 class FITParser : public Parser
 {
 public:
-	FITParser(QList<TrackData> &tracks, QList<RouteData> &routes,
-	  QList<Waypoint> &waypoints);
+	FITParser();
 	~FITParser() {}
 
-	bool loadFile(QFile *file);
+	bool parse(QFile *file, QList<TrackData> &tracks, QList<RouteData> &routes,
+	  QList<Waypoint> &waypoints);
 	QString errorString() const {return _errorString;}
 	int errorLine() const {return 0;}
 
 private:
-	typedef struct {
+	struct FileHeader {
 		quint8 headerSize;
 		quint8 protocolVersion;
 		quint16 profileVersion;
 		quint32 dataSize;
 		quint32 magic;
-	} FileHeader;
+	};
 
-	typedef struct {
+	struct Field {
 		quint8 id;
 		quint8 size;
 		quint8 type;
-	} Field;
+	};
 
-	typedef struct {
+	struct MessageDefinition {
 		quint8 endian;
 		quint16 globalId;
 		quint8 numFields;
 		Field *fields;
 		quint8 numDevFields;
 		Field *devFields;
-	} MessageDefinition;
+	};
 
 
 	void warning(const char *text) const;
@@ -47,11 +47,11 @@ private:
 	bool skipValue(size_t size);
 
 	bool parseHeader();
-	bool parseRecord();
+	bool parseRecord(TrackData &track);
 	bool parseDefinitionMessage(quint8 header);
-	bool parseCompressedMessage(quint8 header);
-	bool parseDataMessage(quint8 header);
-	bool parseData(MessageDefinition *def, quint8 offset);
+	bool parseCompressedMessage(TrackData &track, quint8 header);
+	bool parseDataMessage(TrackData &track, quint8 header);
+	bool parseData(TrackData &track, MessageDefinition *def, quint8 offset);
 	bool readField(Field *f, quint32 &val);
 
 	QIODevice *_device;
