@@ -4,6 +4,5 @@ QDebug operator<<(QDebug dbg, const GraphPoint &point)
 {
 	dbg.nospace() << "GraphPoint(" << point.s() << ", " << point.t() << ", "
 	  << point.y() << ")";
-
-	return dbg.maybeSpace();
+	return dbg.space();
 }
