@@ -19,8 +19,9 @@ public:
 
 	virtual QString label() const = 0;
 	virtual void loadData(const Data &data, const QList<PathItem *> &paths) = 0;
-	virtual void clear() {}
-	virtual void setUnits(enum Units units) {Q_UNUSED(units)}
+	virtual void clear() {GraphView::clear();}
+	virtual void setUnits(enum Units units) {GraphView::setUnits(units);}
+	virtual void setGraphType(GraphType type) {GraphView::setGraphType(type);}
 	virtual void setTimeType(enum TimeType type) {Q_UNUSED(type)}
 	virtual void showTracks(bool show) {Q_UNUSED(show)}
 	virtual void showRoutes(bool show) {Q_UNUSED(show)}
