@@ -68,7 +68,7 @@ GUI::GUI()
 	createToolBars();
 
 	createBrowser();
-	
+
 	QSplitter *splitter = new QSplitter();
 	splitter->setOrientation(Qt::Vertical);
 	splitter->setChildrenCollapsible(false);
@@ -220,25 +220,7 @@ void GUI::ShowContextMenu(const QPoint &pos)
 	contextMenu.addAction(_showMapWidgetAction);
 	contextMenu.exec(mapToGlobal(pos));
 }
-#endif
-const QString GUI::fileFormats() const
-{
-	return tr("Supported files (*.csv *.fit *.gpx *.igc *.kml *.nmea *.tcx)")
-	  + ";;" + tr("CSV files (*.csv)") + ";;" + tr("FIT files (*.fit)") + ";;"
-	  + tr("GPX files (*.gpx)") + ";;" + tr("IGC files (*.igc)") + ";;"
-	  + tr("KML files (*.kml)") + ";;" + tr("NMEA files (*.nmea)") + ";;"
-	  + tr("TCX files (*.tcx)") + ";;" + tr("All files (*)");
-}
 
-void GUI::createBrowser()
-{
-	QStringList filter;
-	filter << "*.gpx" << "*.tcx" << "*.kml" << "*.fit" << "*.csv" << "*.igc"
-	  << "*.nmea";
-	_browser = new FileBrowser(this);
-	_browser->setFilter(filter);
-}
-#ifdef Q_WS_MAEMO_5
 void GUI::onProcessStarted()
 {
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
@@ -248,6 +230,7 @@ void GUI::onProcessReady()
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 }
 #endif
+
 void GUI::loadDatums()
 {
 	QString ef, df;
@@ -303,7 +286,7 @@ void GUI::loadMaps()
 	else if (QFile::exists(GLOBAL_MAP_FILE))
 		online = GLOBAL_MAP_FILE;
 
-	if (!online.isNull() && !_ml->loadList(online))
+	if (!online.isNull() && !_ml->loadFile(online))
 		qWarning("%s: %s", qPrintable(online), qPrintable(_ml->errorString()));
 
 
@@ -315,12 +298,10 @@ void GUI::loadMaps()
 	if (!offline.isNull()) {
 		QDir md(offline);
 		QFileInfoList ml = md.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot);
-		QStringList filters;
-		filters << "*.map" << "*.tba" << "*.tar";
 
 		for (int i = 0; i < ml.size(); i++) {
 			QDir dir(ml.at(i).absoluteFilePath());
-			QFileInfoList fl = dir.entryInfoList(filters, QDir::Files);
+			QFileInfoList fl = dir.entryInfoList(MapList::filter(), QDir::Files);
 
 			if (fl.isEmpty())
 				qWarning("%s: no map/atlas file found",
@@ -329,13 +310,13 @@ void GUI::loadMaps()
 				qWarning("%s: ambiguous directory content",
 				  qPrintable(ml.at(i).absoluteFilePath()));
 			else
-				if (!_ml->loadMap(fl.first().absoluteFilePath()))
+				if (!_ml->loadFile(fl.first().absoluteFilePath()))
 					qWarning("%s: %s", qPrintable(fl.first().absoluteFilePath()),
 					  qPrintable(_ml->errorString()));
 		}
 	}
 
-	_map = _ml->maps().isEmpty() ? new EmptyMap(this) : _ml->maps().first();
+	_map = new EmptyMap(this);
 }
 
 void GUI::loadPOIs()
@@ -362,6 +343,12 @@ void GUI::loadPOIs()
 	}
 }
 
+void GUI::createBrowser()
+{
+	_browser = new FileBrowser(this);
+	_browser->setFilter(Data::filter());
+}
+
 void GUI::createMapActions()
 {
 	_mapsSignalMapper = new QSignalMapper(this);
@@ -511,7 +498,7 @@ void GUI::createActions()
 	  tr("Load map..."), this);
 	connect(_loadMapAction, SIGNAL(triggered()), this, SLOT(loadMap()));
 	_clearMapCacheAction = new QAction(tr("Clear tile cache"), this);
-	connect(_clearMapCacheAction, SIGNAL(triggered()), this,
+	connect(_clearMapCacheAction, SIGNAL(triggered()), _pathView,
 	  SLOT(clearMapCache()));
 	createMapActions();
 	_nextMapAction = new QAction(tr("Next map"), this);
@@ -578,14 +565,12 @@ void GUI::createActions()
 	_distanceGraphAction = new QAction(tr("Distance"), this);
 	_distanceGraphAction->setCheckable(true);
 	_distanceGraphAction->setActionGroup(ag);
-	_distanceGraphAction->setShortcut(DISTANCE_GRAPH_SHORTCUT);
 	connect(_distanceGraphAction, SIGNAL(triggered()), this,
 	  SLOT(setDistanceGraph()));
 	addAction(_distanceGraphAction);
 	_timeGraphAction = new QAction(tr("Time"), this);
 	_timeGraphAction->setCheckable(true);
 	_timeGraphAction->setActionGroup(ag);
-	_timeGraphAction->setShortcut(TIME_GRAPH_SHORTCUT);
 	connect(_timeGraphAction, SIGNAL(triggered()), this,
 	  SLOT(setTimeGraph()));
 	addAction(_timeGraphAction);
@@ -593,6 +578,10 @@ void GUI::createActions()
 	_showGraphGridAction->setCheckable(true);
 	connect(_showGraphGridAction, SIGNAL(triggered(bool)), this,
 	  SLOT(showGraphGrids(bool)));
+	_showGraphSliderInfoAction = new QAction(tr("Show slider info"), this);
+	_showGraphSliderInfoAction->setCheckable(true);
+	connect(_showGraphSliderInfoAction, SIGNAL(triggered(bool)), this,
+	  SLOT(showGraphSliderInfo(bool)));
 
 	// Settings actions
 	_showToolbarsAction = new QAction(tr("Show toolbars"), this);
@@ -776,6 +765,7 @@ void GUI::createMenus()
 	graphMenu->addAction(_timeGraphAction);
 	graphMenu->addSeparator();
 	graphMenu->addAction(_showGraphGridAction);
+	graphMenu->addAction(_showGraphSliderInfoAction);
 	graphMenu->addSeparator();
 	graphMenu->addAction(_showGraphsAction);
 
@@ -939,7 +929,7 @@ void GUI::keys()
 	msgBox.setWindowTitle(tr("Keyboard controls"));
 	msgBox.setText(QString("<h3>") + tr("Keyboard controls") + QString("</h3>"));
 	msgBox.setInformativeText(
-	  QString("<div><table width=\"400\"><tr><td>") + tr("Next file")
+	  QString("<div><table width=\"500\"><tr><td>") + tr("Next file")
 	  + QString("</td><td><i>RIGHT</i></td></tr><tr><td>") + tr("Previous file")
 	  + QString("</td><td><i>LEFT</i></td></tr><tr><td>")
 	  + tr("First file") + QString("</td><td><i>UP</i></td></tr><tr><td>")
@@ -969,10 +959,10 @@ void GUI::keys()
 	  + _showStatusbarAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
 	  + tr("Show Toolbar") + QString("</td><td><i>")
 	  + _showToolbarsAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
-	  + tr("Distance") + QString("</td><td><i>")
-	  + _distanceGraphAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
-	  + tr("Time") + QString("</td><td><i>")
-	  + _timeGraphAction->shortcut().toString() + QString("</i></td></tr><tr><td>")
+	  + tr("Toggle graph type") + "</td><td><i>"
+	  + QKeySequence(TOGGLE_GRAPH_TYPE_KEY).toString() + "</i></td></tr><tr><td>"
+	  + tr("Toggle time type") + "</td><td><i>"
+	  + QKeySequence(TOGGLE_TIME_TYPE_KEY).toString() + QString("</i></td></tr><tr><td>")
 	  + tr("Fullscreen") + QString("</td><td><i>")
 	  + _fullscreenAction->shortcut().toString() + QString("</i></td></tr>"
 	  "</table></div>"));
@@ -988,11 +978,23 @@ void GUI::keys()
 	  + "</i></td></tr><tr><td>" + tr("First file") + "</td><td><i>"
 	  + QKeySequence(FIRST_KEY).toString() + "</i></td></tr><tr><td>"
 	  + tr("Last file") + "</td><td><i>" + QKeySequence(LAST_KEY).toString()
-	  + "</i></td></tr><tr><td>" + tr("Append modifier")
-	  + "</td><td><i>SHIFT</i></td></tr><tr><td></td><td></td></tr><tr><td>"
-	  + tr("Next map") + "</td><td><i>" + NEXT_MAP_SHORTCUT.toString()
-	  + "</i></td></tr><tr><td>" + tr("Previous map") + "</td><td><i>"
-	  + PREV_MAP_SHORTCUT.toString() + "</i></td></tr></table></div>");
+	  + "</i></td></tr><tr><td>" + tr("Append file")
+	  + "</td><td><i>" + QKeySequence(MODIFIER).toString() + tr("Next/Previous")
+	  + "</i></td></tr><tr><td></td><td></td></tr><tr><td>"
+	  + tr("Toggle graph type") + "</td><td><i>"
+	  + QKeySequence(TOGGLE_GRAPH_TYPE_KEY).toString() + "</i></td></tr><tr><td>"
+	  + tr("Toggle time type") + "</td><td><i>"
+	  + QKeySequence(TOGGLE_TIME_TYPE_KEY).toString()
+	  + "<tr><td></td><td></td></tr><tr><td>" + tr("Next map")
+	  + "</td><td><i>" + NEXT_MAP_SHORTCUT.toString() + "</i></td></tr><tr><td>"
+	  + tr("Previous map") + "</td><td><i>" + PREV_MAP_SHORTCUT.toString()
+	  + "</i></td></tr><tr><td></td><td></td></tr><tr><td>" + tr("Zoom in")
+	  + "</td><td><i>" + QKeySequence(ZOOM_IN).toString()
+	  + "</i></td></tr><tr><td>" + tr("Zoom out") + "</td><td><i>"
+	  + QKeySequence(ZOOM_OUT).toString() + "</i></td></tr><tr><td>"
+	  + tr("Digital zoom") + "</td><td><i>" + QKeySequence(MODIFIER).toString()
+	  + tr("Zoom") + "</i></td></tr></table></div>");
+
 #endif
 	msgBox.exec();
 }
@@ -1009,10 +1011,11 @@ void GUI::dataSources()
 		"following file:")
 	  + "</p><p><code>" + USER_MAP_FILE + "</code></p><p>"
 	  + tr("The file format is one map entry per line, consisting of the map "
-		"name and tiles URL delimited by a TAB character. The tile X and Y "
-		"coordinates are replaced with $x and $y in the URL and the zoom "
-		"level is replaced with $z. An example map file could look like:")
-	  + "</p><p><code>Map1	http://tile.server.com/map/$z/$x/$y.png"
+		"name, tiles URL and an optional maximal zoom level delimited by "
+	    "a TAB character. The tile X and Y coordinates are replaced with $x "
+	    "and $y in the URL and the zoom level is replaced with $z. An example "
+	    "map file could look like:")
+	  + "</p><p><code>Map1	http://tile.server.com/map/$z/$x/$y.png	15"
 		  "<br/>Map2	http://mapserver.org/map/$z-$x-$y</code></p>"
 
 	  + "<h4>" + tr("Offline maps") + "</h4><p>"
@@ -1035,7 +1038,7 @@ void GUI::dataSources()
 void GUI::openFile()
 {
 	QStringList files = QFileDialog::getOpenFileNames(this, tr("Open file"),
-	  QString(), fileFormats());
+	  QString(), Data::formats());
 	QStringList list = files;
 
 	for (QStringList::Iterator it = list.begin(); it != list.end(); it++)
@@ -1125,7 +1128,7 @@ bool GUI::loadFile(const QString &fileName)
 void GUI::openPOIFile()
 {
 	QStringList files = QFileDialog::getOpenFileNames(this, tr("Open POI file"),
-	  QString(), fileFormats());
+	  QString(), Data::formats());
 	QStringList list = files;
 
 	for (QStringList::Iterator it = list.begin(); it != list.end(); it++)
@@ -1166,20 +1169,22 @@ void GUI::closePOIFiles()
 
 	_poi->clear();
 }
-#ifndef Q_WS_MAEMO_5
-
-void GUI::printFile()
-{
-	QPrinter printer(QPrinter::HighResolution);
-	QPrintDialog dialog(&printer, this);
-
-	if (dialog.exec() == QDialog::Accepted)
-		plot(&printer);
-}
-#endif
 
 void GUI::openOptions()
 {
+#define SET_VIEW_OPTION(option, action) \
+	if (options.option != _options.option) \
+		_pathView->action(options.option)
+#define SET_TAB_OPTION(option, action) \
+	if (options.option != _options.option) \
+		for (int i = 0; i < _tabs.count(); i++) \
+			_tabs.at(i)->action(options.option)
+#define SET_TRACK_OPTION(option, action) \
+	if (options.option != _options.option) { \
+		Track::action(options.option); \
+		reload = true; \
+	}
+
 	Options options(_options);
 	bool reload = false;
 #ifdef Q_WS_MAEMO_5
@@ -1190,71 +1195,36 @@ void GUI::openOptions()
 	if (dialog.exec() != QDialog::Accepted)
 		return;
 
-	if (options.palette != _options.palette) {
-		_pathView->setPalette(options.palette);
-		for (int i = 0; i < _tabs.count(); i++)
-			_tabs.at(i)->setPalette(options.palette);
-	}
-	if (options.trackWidth != _options.trackWidth)
-		_pathView->setTrackWidth(options.trackWidth);
-	if (options.routeWidth != _options.routeWidth)
-		_pathView->setRouteWidth(options.routeWidth);
-	if (options.trackStyle != _options.trackStyle)
-		_pathView->setTrackStyle(options.trackStyle);
-	if (options.routeStyle != _options.routeStyle)
-		_pathView->setRouteStyle(options.routeStyle);
-	if (options.pathAntiAliasing != _options.pathAntiAliasing)
-		_pathView->setRenderHint(QPainter::Antialiasing,
-		  options.pathAntiAliasing);
-	if (options.graphWidth != _options.graphWidth)
-		for (int i = 0; i < _tabs.count(); i++)
-			_tabs.at(i)->setGraphWidth(options.graphWidth);
-	if (options.graphAntiAliasing != _options.graphAntiAliasing)
-		for (int i = 0; i < _tabs.count(); i++)
-			_tabs.at(i)->setRenderHint(QPainter::Antialiasing,
-			  options.graphAntiAliasing);
+	SET_VIEW_OPTION(palette, setPalette);
+	SET_VIEW_OPTION(mapOpacity, setMapOpacity);
+	SET_VIEW_OPTION(backgroundColor, setBackgroundColor);
+	SET_VIEW_OPTION(trackWidth, setTrackWidth);
+	SET_VIEW_OPTION(routeWidth, setRouteWidth);
+	SET_VIEW_OPTION(trackStyle, setTrackStyle);
+	SET_VIEW_OPTION(routeStyle, setRouteStyle);
+	SET_VIEW_OPTION(waypointSize, setWaypointSize);
+	SET_VIEW_OPTION(waypointColor, setWaypointColor);
+	SET_VIEW_OPTION(poiSize, setPOISize);
+	SET_VIEW_OPTION(poiColor, setPOIColor);
+	SET_VIEW_OPTION(pathAntiAliasing, useAntiAliasing);
+	SET_VIEW_OPTION(useOpenGL, useOpenGL);
 
-	if (options.elevationFilter != _options.elevationFilter) {
-		Track::setElevationFilter(options.elevationFilter);
-		reload = true;
-	}
-	if (options.speedFilter != _options.speedFilter) {
-		Track::setSpeedFilter(options.speedFilter);
-		reload = true;
-	}
-	if (options.heartRateFilter != _options.heartRateFilter) {
-		Track::setHeartRateFilter(options.heartRateFilter);
-		reload = true;
-	}
-	if (options.cadenceFilter != _options.cadenceFilter) {
-		Track::setCadenceFilter(options.cadenceFilter);
-		reload = true;
-	}
-	if (options.powerFilter != _options.powerFilter) {
-		Track::setPowerFilter(options.powerFilter);
-		reload = true;
-	}
-	if (options.outlierEliminate != _options.outlierEliminate) {
-		Track::setOutlierElimination(options.outlierEliminate);
-		reload = true;
-	}
-	if (options.pauseSpeed != _options.pauseSpeed) {
-		Track::setPauseSpeed(options.pauseSpeed);
-		reload = true;
-	}
-	if (options.pauseInterval != _options.pauseInterval) {
-		Track::setPauseInterval(options.pauseInterval);
-		reload = true;
-	}
+	SET_TAB_OPTION(palette, setPalette);
+	SET_TAB_OPTION(graphWidth, setGraphWidth);
+	SET_TAB_OPTION(graphAntiAliasing, useAntiAliasing);
+	SET_TAB_OPTION(useOpenGL, useOpenGL);
+
+	SET_TRACK_OPTION(elevationFilter, setElevationFilter);
+	SET_TRACK_OPTION(speedFilter, setSpeedFilter);
+	SET_TRACK_OPTION(heartRateFilter, setHeartRateFilter);
+	SET_TRACK_OPTION(cadenceFilter, setCadenceFilter);
+	SET_TRACK_OPTION(powerFilter, setPowerFilter);
+	SET_TRACK_OPTION(outlierEliminate, setOutlierElimination);
+	SET_TRACK_OPTION(pauseSpeed, setPauseSpeed);
+	SET_TRACK_OPTION(pauseInterval, setPauseInterval);
 
 	if (options.poiRadius != _options.poiRadius)
 		_poi->setRadius(options.poiRadius);
-
-	if (options.useOpenGL != _options.useOpenGL) {
-		_pathView->useOpenGL(options.useOpenGL);
-		for (int i = 0; i < _tabs.count(); i++)
-			_tabs.at(i)->useOpenGL(options.useOpenGL);
-	}
 	if (options.pixmapCache != _options.pixmapCache)
 		QPixmapCache::setCacheLimit(options.pixmapCache * 1024);
 
@@ -1264,6 +1234,17 @@ void GUI::openOptions()
 	_options = options;
 }
 
+#ifndef Q_WS_MAEMO_5
+void GUI::printFile()
+{
+	QPrinter printer(QPrinter::HighResolution);
+	QPrintDialog dialog(&printer, this);
+
+	if (dialog.exec() == QDialog::Accepted)
+		plot(&printer);
+}
+#endif
+
 void GUI::exportFile()
 {
 #ifdef Q_WS_MAEMO_5
@@ -1288,6 +1269,7 @@ void GUI::exportFile()
 	printer.setOutputFormat(QPrinter::PdfFormat);
 	printer.setCreator(QString(APP_NAME) + QString(" ")
 	  + QString(APP_VERSION));
+	printer.setResolution(_export.resolution);
 	printer.setOrientation(_export.orientation);
 	printer.setOutputFileName(_export.fileName);
 	printer.setPaperSize(_export.paperSize);
@@ -1343,35 +1325,36 @@ void GUI::plot(QPrinter *printer)
 	if (tm > 0 && _options.printMovingTime)
 		info.insert(tr("Moving time"), Format::timeSpan(tm));
 
-
-	ratio = p.paintEngine()->paintDevice()->logicalDpiX() / SCREEN_DPI;
+	qreal fsr = 1085.0 / (qMax(printer->width(), printer->height())
+	  / (qreal)printer->resolution());
+	ratio = p.paintEngine()->paintDevice()->logicalDpiX() / fsr;
 	if (info.isEmpty()) {
 		ih = 0;
 		mh = 0;
 	} else {
 		ih = info.contentSize().height() * ratio;
 		mh = ih / 2;
-		info.plot(&p, QRectF(0, 0, printer->width(), ih));
+		info.plot(&p, QRectF(0, 0, printer->width(), ih), ratio);
 	}
 	if (_graphTabWidget->isVisible() && !_options.separateGraphPage) {
 		qreal r = (((qreal)(printer)->width()) / (qreal)(printer->height()));
 		gh = (printer->width() > printer->height())
 		  ? 0.15 * r * (printer->height() - ih - 2*mh)
 		  : 0.15 * (printer->height() - ih - 2*mh);
-		gh = qMax(gh, ratio * 150);
 		GraphTab *gt = static_cast<GraphTab*>(_graphTabWidget->currentWidget());
-		gt->plot(&p,  QRectF(0, printer->height() - gh, printer->width(), gh));
+		gt->plot(&p,  QRectF(0, printer->height() - gh, printer->width(), gh),
+		  ratio);
 	} else
 		gh = 0;
 	_pathView->plot(&p, QRectF(0, ih + mh, printer->width(), printer->height()
-	  - (ih + 2*mh + gh)));
+	  - (ih + 2*mh + gh)), ratio, _options.hiresPrint);
 
 	if (_graphTabWidget->isVisible() && _options.separateGraphPage) {
 		printer->newPage();
 
 		int cnt = 0;
 		for (int i = 0; i < _tabs.size(); i++)
-			if (_tabs.at(i)->count())
+			if (!_tabs.at(i)->isEmpty())
 				cnt++;
 
 		double sp = ratio * 20;
@@ -1380,8 +1363,9 @@ void GUI::plot(QPrinter *printer)
 
 		qreal y = 0;
 		for (int i = 0; i < _tabs.size(); i++) {
-			if (_tabs.at(i)->count()) {
-				_tabs.at(i)->plot(&p,  QRectF(0, y, printer->width(), gh));
+			if (!_tabs.at(i)->isEmpty()) {
+				_tabs.at(i)->plot(&p,  QRectF(0, y, printer->width(), gh),
+				  ratio);
 				y += gh + sp;
 			}
 		}
@@ -1567,25 +1551,34 @@ void GUI::showGraphGrids(bool show)
 		_tabs.at(i)->showGrid(show);
 }
 
+void GUI::showGraphSliderInfo(bool show)
+{
+	for (int i = 0; i < _tabs.size(); i++)
+		_tabs.at(i)->showSliderInfo(show);
+}
+
 void GUI::loadMap()
 {
 	QString fileName = QFileDialog::getOpenFileName(this, tr("Open map file"),
-	  QString(), tr("Map files (*.map *.tba *.tar)"));
+	  QString(), MapList::formats());
 
 	if (fileName.isEmpty())
 		return;
 
-	if (_ml->loadMap(fileName)) {
-		QAction *a = new QAction(_ml->maps().last()->name(), this);
-		a->setCheckable(true);
-		a->setActionGroup(_mapsActionGroup);
-		_mapsSignalMapper->setMapping(a, _ml->maps().size() - 1);
-		connect(a, SIGNAL(triggered()), _mapsSignalMapper, SLOT(map()));
-		_mapActions.append(a);
-		_mapMenu->insertAction(_mapsEnd, a);
+	int count = _ml->maps().count();
+	if (_ml->loadFile(fileName)) {
+		for (int i = count; i < _ml->maps().count(); i++) {
+			QAction *a = new QAction(_ml->maps().at(i)->name(), this);
+			a->setCheckable(true);
+			a->setActionGroup(_mapsActionGroup);
+			_mapsSignalMapper->setMapping(a, i);
+			connect(a, SIGNAL(triggered()), _mapsSignalMapper, SLOT(map()));
+			_mapActions.append(a);
+			_mapMenu->insertAction(_mapsEnd, a);
+		}
 		_showMapAction->setEnabled(true);
 		_clearMapCacheAction->setEnabled(true);
-		a->activate(QAction::Trigger);
+		_mapActions.last()->activate(QAction::Trigger);
 	} else {
 		QString error = tr("Error loading map:") + "\n\n"
 		  + fileName + "\n\n" + _ml->errorString();
@@ -1593,12 +1586,6 @@ void GUI::loadMap()
 	}
 }
 
-void GUI::clearMapCache()
-{
-	_map->clearCache();
-	_pathView->redraw();
-}
-
 void GUI::updateStatusBarInfo()
 {
 	if (_files.count() == 0)
@@ -1718,13 +1705,13 @@ void GUI::updateGraphTabs()
 
 	for (int i = 0; i < _tabs.size(); i++) {
 		tab = _tabs.at(i);
-		if (!tab->count() && (index = _graphTabWidget->indexOf(tab)) >= 0)
+		if (tab->isEmpty() && (index = _graphTabWidget->indexOf(tab)) >= 0)
 			_graphTabWidget->removeTab(index);
 	}
 
 	for (int i = 0; i < _tabs.size(); i++) {
 		tab = _tabs.at(i);
-		if (tab->count() && _graphTabWidget->indexOf(tab) < 0)
+		if (!tab->isEmpty() && _graphTabWidget->indexOf(tab) < 0)
 			_graphTabWidget->insertTab(i, tab, _tabs.at(i)->label());
 	}
 
@@ -1839,6 +1826,20 @@ void GUI::keyPressEvent(QKeyEvent *event)
 			emit s_zoom("out");
 			break;
 #endif
+
+		case TOGGLE_GRAPH_TYPE_KEY:
+			if (_timeGraphAction->isChecked())
+				_distanceGraphAction->activate(QAction::Trigger);
+			else
+				_timeGraphAction->activate(QAction::Trigger);
+			break;
+		case TOGGLE_TIME_TYPE_KEY:
+			if (_movingTimeAction->isChecked())
+				_totalTimeAction->activate(QAction::Trigger);
+			else
+				_movingTimeAction->activate(QAction::Trigger);
+			break;
+
 		case Qt::Key_Escape:
 			if (_fullscreenAction->isChecked()) {
 				_fullscreenAction->setChecked(false);
@@ -1941,6 +1942,10 @@ void GUI::writeSettings()
 	if (_showGraphGridAction->isChecked() != SHOW_GRAPH_GRIDS_DEFAULT)
 		settings.setValue(SHOW_GRAPH_GRIDS_SETTING,
 		  _showGraphGridAction->isChecked());
+	if (_showGraphSliderInfoAction->isChecked()
+	  != SHOW_GRAPH_SLIDER_INFO_DEFAULT)
+		settings.setValue(SHOW_GRAPH_SLIDER_INFO_SETTING,
+		  _showGraphSliderInfoAction->isChecked());
 	settings.endGroup();
 
 	settings.beginGroup(POI_SETTINGS_GROUP);
@@ -1981,6 +1986,8 @@ void GUI::writeSettings()
 	settings.beginGroup(EXPORT_SETTINGS_GROUP);
 	if (_export.orientation != PAPER_ORIENTATION_DEFAULT)
 		settings.setValue(PAPER_ORIENTATION_SETTING, _export.orientation);
+	if (_export.resolution != RESOLUTION_DEFAULT)
+		settings.setValue(RESOLUTION_SETTING, _export.resolution);
 	if (_export.paperSize != PAPER_SIZE_DEFAULT)
 		settings.setValue(PAPER_SIZE_SETTING, _export.paperSize);
 	if (_export.margins.left() != MARGIN_LEFT_DEFAULT)
@@ -2000,6 +2007,10 @@ void GUI::writeSettings()
 		settings.setValue(PALETTE_COLOR_SETTING, _options.palette.color());
 	if (_options.palette.shift() != PALETTE_SHIFT_DEFAULT)
 		settings.setValue(PALETTE_SHIFT_SETTING, _options.palette.shift());
+	if (_options.mapOpacity != MAP_OPACITY_DEFAULT)
+		settings.setValue(MAP_OPACITY_SETTING, _options.mapOpacity);
+	if (_options.backgroundColor != BACKGROUND_COLOR_DEFAULT)
+		settings.setValue(BACKGROUND_COLOR_SETTING, _options.backgroundColor);
 	if (_options.trackWidth != TRACK_WIDTH_DEFAULT)
 		settings.setValue(TRACK_WIDTH_SETTING, _options.trackWidth);
 	if (_options.routeWidth != ROUTE_WIDTH_DEFAULT)
@@ -2008,6 +2019,14 @@ void GUI::writeSettings()
 		settings.setValue(TRACK_STYLE_SETTING, (int)_options.trackStyle);
 	if (_options.routeStyle != ROUTE_STYLE_DEFAULT)
 		settings.setValue(ROUTE_STYLE_SETTING, (int)_options.routeStyle);
+	if (_options.waypointSize != WAYPOINT_SIZE_DEFAULT)
+		settings.setValue(WAYPOINT_SIZE_SETTING, _options.waypointSize);
+	if (_options.waypointColor != WAYPOINT_COLOR_DEFAULT)
+		settings.setValue(WAYPOINT_COLOR_SETTING, _options.waypointColor);
+	if (_options.poiSize != POI_SIZE_DEFAULT)
+		settings.setValue(POI_SIZE_SETTING, _options.poiSize);
+	if (_options.poiColor != POI_COLOR_DEFAULT)
+		settings.setValue(POI_COLOR_SETTING, _options.poiColor);
 	if (_options.graphWidth != GRAPH_WIDTH_DEFAULT)
 		settings.setValue(GRAPH_WIDTH_SETTING, _options.graphWidth);
 	if (_options.pathAntiAliasing != PATH_AA_DEFAULT)
@@ -2036,6 +2055,8 @@ void GUI::writeSettings()
 		settings.setValue(USE_OPENGL_SETTING, _options.useOpenGL);
 	if (_options.pixmapCache != PIXMAP_CACHE_DEFAULT)
 		settings.setValue(PIXMAP_CACHE_SETTING, _options.pixmapCache);
+	if (_options.hiresPrint != HIRES_PRINT_DEFAULT)
+		settings.setValue(HIRES_PRINT_SETTING, _options.hiresPrint);
 	if (_options.printName != PRINT_NAME_DEFAULT)
 		settings.setValue(PRINT_NAME_SETTING, _options.printName);
 	if (_options.printDate != PRINT_DATE_DEFAULT)
@@ -2098,9 +2119,7 @@ void GUI::readSettings()
 		_showMapAction->setChecked(true);
 	if (_ml->maps().count()) {
 		int index = mapIndex(settings.value(CURRENT_MAP_SETTING).toString());
-		_mapActions.at(index)->setChecked(true);
-		_map = _ml->maps().at(index);
-		_pathView->setMap(_map);
+		_mapActions.at(index)->trigger();
 	}
 	settings.endGroup();
 
@@ -2120,6 +2139,11 @@ void GUI::readSettings()
 		showGraphGrids(false);
 	else
 		_showGraphGridAction->setChecked(true);
+	if (!settings.value(SHOW_GRAPH_SLIDER_INFO_SETTING,
+	  SHOW_GRAPH_SLIDER_INFO_DEFAULT).toBool())
+		showGraphSliderInfo(false);
+	else
+		_showGraphSliderInfoAction->setChecked(true);
 	settings.endGroup();
 
 	settings.beginGroup(POI_SETTINGS_GROUP);
@@ -2183,6 +2207,8 @@ void GUI::readSettings()
 	settings.beginGroup(EXPORT_SETTINGS_GROUP);
 	_export.orientation = (QPrinter::Orientation) settings.value(
 	  PAPER_ORIENTATION_SETTING, PAPER_ORIENTATION_DEFAULT).toInt();
+	_export.resolution = settings.value(RESOLUTION_SETTING, RESOLUTION_DEFAULT)
+	  .toInt();
 	_export.paperSize = (QPrinter::PaperSize) settings.value(PAPER_SIZE_SETTING,
 	  PAPER_SIZE_DEFAULT).toInt();
 	qreal ml = settings.value(MARGIN_LEFT_SETTING, MARGIN_LEFT_DEFAULT)
@@ -2203,6 +2229,10 @@ void GUI::readSettings()
 	qreal ps = settings.value(PALETTE_SHIFT_SETTING, PALETTE_SHIFT_DEFAULT)
 	  .toDouble();
 	_options.palette = Palette(pc, ps);
+	_options.mapOpacity = settings.value(MAP_OPACITY_SETTING,
+	  MAP_OPACITY_DEFAULT).toInt();
+	_options.backgroundColor = settings.value(BACKGROUND_COLOR_SETTING,
+	  BACKGROUND_COLOR_DEFAULT).value<QColor>();
 	_options.trackWidth = settings.value(TRACK_WIDTH_SETTING,
 	  TRACK_WIDTH_DEFAULT).toInt();
 	_options.routeWidth = settings.value(ROUTE_WIDTH_SETTING,
@@ -2213,6 +2243,14 @@ void GUI::readSettings()
 	  (int)ROUTE_STYLE_DEFAULT).toInt();
 	_options.pathAntiAliasing = settings.value(PATH_AA_SETTING, PATH_AA_DEFAULT)
 	  .toBool();
+	_options.waypointSize = settings.value(WAYPOINT_SIZE_SETTING,
+	  WAYPOINT_SIZE_DEFAULT).toInt();
+	_options.waypointColor = settings.value(WAYPOINT_COLOR_SETTING,
+	  WAYPOINT_COLOR_DEFAULT).value<QColor>();
+	_options.poiSize = settings.value(POI_SIZE_SETTING, POI_SIZE_DEFAULT)
+	  .toInt();
+	_options.poiColor = settings.value(POI_COLOR_SETTING, POI_COLOR_DEFAULT)
+	  .value<QColor>();
 	_options.graphWidth = settings.value(GRAPH_WIDTH_SETTING,
 	  GRAPH_WIDTH_DEFAULT).toInt();
 	_options.graphAntiAliasing = settings.value(GRAPH_AA_SETTING,
@@ -2239,6 +2277,8 @@ void GUI::readSettings()
 	  .toBool();
 	_options.pixmapCache = settings.value(PIXMAP_CACHE_SETTING,
 	  PIXMAP_CACHE_DEFAULT).toInt();
+	_options.hiresPrint = settings.value(HIRES_PRINT_SETTING,
+	  HIRES_PRINT_DEFAULT).toBool();
 	_options.printName = settings.value(PRINT_NAME_SETTING, PRINT_NAME_DEFAULT)
 	  .toBool();
 	_options.printDate = settings.value(PRINT_DATE_SETTING, PRINT_DATE_DEFAULT)
@@ -2255,10 +2295,16 @@ void GUI::readSettings()
 	  SEPARATE_GRAPH_PAGE_DEFAULT).toBool();
 
 	_pathView->setPalette(_options.palette);
+	_pathView->setMapOpacity(_options.mapOpacity);
+	_pathView->setBackgroundColor(_options.backgroundColor);
 	_pathView->setTrackWidth(_options.trackWidth);
 	_pathView->setRouteWidth(_options.routeWidth);
 	_pathView->setTrackStyle(_options.trackStyle);
 	_pathView->setRouteStyle(_options.routeStyle);
+	_pathView->setWaypointSize(_options.waypointSize);
+	_pathView->setWaypointColor(_options.waypointColor);
+	_pathView->setPOISize(_options.poiSize);
+	_pathView->setPOIColor(_options.poiColor);
 	_pathView->setRenderHint(QPainter::Antialiasing, _options.pathAntiAliasing);
 	if (_options.useOpenGL)
 		_pathView->useOpenGL(true);
