@@ -10,6 +10,9 @@
 #define LAST_KEY                Qt::Key_Down
 #define MODIFIER                Qt::ShiftModifier
 
+#define TOGGLE_GRAPH_TYPE_KEY   Qt::Key_X
+#define TOGGLE_TIME_TYPE_KEY    Qt::Key_T
+
 #define QUIT_SHORTCUT           QKeySequence(QKeySequence::Quit)
 #define OPEN_SHORTCUT           QKeySequence(QKeySequence::Open)
 #define CLOSE_SHORTCUT          QKeySequence(QKeySequence::Close)
@@ -36,6 +39,9 @@
 #define ZOOM_IN                 QKeySequence::ZoomIn
 #define ZOOM_OUT                QKeySequence::ZoomOut
 
+#define TOGGLE_GRAPH_TYPE_KEY   Qt::Key_X
+#define TOGGLE_TIME_TYPE_KEY    Qt::Key_T
+
 #define QUIT_SHORTCUT           QKeySequence(QKeySequence::Quit)
 #define OPEN_SHORTCUT           QKeySequence(QKeySequence::Open)
 #define CLOSE_SHORTCUT          QKeySequence(QKeySequence::Close)
@@ -46,8 +52,6 @@
 #define NEXT_MAP_SHORTCUT       QKeySequence(QKeySequence::Forward)
 #define PREV_MAP_SHORTCUT       QKeySequence(QKeySequence::Back)
 #define SHOW_GRAPHS_SHORTCUT    QKeySequence(Qt::CTRL + Qt::Key_G)
-#define DISTANCE_GRAPH_SHORTCUT QKeySequence(Qt::CTRL + Qt::Key_D)
-#define TIME_GRAPH_SHORTCUT     QKeySequence(Qt::CTRL + Qt::Key_T)
 
 #ifdef Q_OS_MAC
 #define FULLSCREEN_SHORTCUT     QKeySequence(Qt::META + Qt::CTRL + Qt::Key_F)
