@@ -12,14 +12,21 @@ class MapList : public QObject
 public:
 	MapList(QObject *parent = 0) : QObject(parent) {}
 
-	bool loadMap(const QString &path);
-	bool loadList(const QString &path);
+	bool loadFile(const QString &path);
 
-	QList<Map*> &maps() {return _maps;}
+	const QList<Map*> &maps() const {return _maps;}
 	const QString &errorString() const {return _errorString;}
 
+	static QString formats();
+	static QStringList filter();
+
 private:
-	bool loadListEntry(const QByteArray &line);
+	Map *loadListEntry(const QByteArray &line);
+
+	bool loadList(const QString &path);
+	bool loadMap(const QString &path);
+	bool loadTba(const QString &path);
+	bool loadTar(const QString &path);
 
 	QList<Map*> _maps;
 	QString _errorString;
