@@ -3,6 +3,7 @@
 
 #include <cstddef>
 #include <cfloat>
+#include <QDebug>
 
 class Matrix {
 public:
@@ -30,4 +31,6 @@ private:
 	size_t _w;
 };
 
+QDebug operator<<(QDebug dbg, const Matrix &matrix);
+
 #endif // MATRIX_H
