@@ -15,6 +15,10 @@ struct Options {
 	int routeWidth;
 	Qt::PenStyle trackStyle;
 	Qt::PenStyle routeStyle;
+	QColor waypointColor;
+	QColor poiColor;
+	int waypointSize;
+	int poiSize;
 	int graphWidth;
 	bool pathAntiAliasing;
 	bool graphAntiAliasing;
@@ -33,6 +37,7 @@ struct Options {
 	bool useOpenGL;
 	int pixmapCache;
 	// Print/Export
+	bool hiresPrint;
 	bool printName;
 	bool printDate;
 	bool printDistance;
@@ -40,6 +45,9 @@ struct Options {
 	bool printMovingTime;
 	bool printItemCount;
 	bool separateGraphPage;
+	// Map
+	int mapOpacity;
+	QColor backgroundColor;
 
 	Units units;
 };
@@ -54,12 +62,19 @@ public:
 
 private slots:
 	void on_pushButton_color_base_clicked();
+	void on_pushButton_color_waypoints_clicked();
+	void on_pushButton_color_pois_clicked();
+	void on_pushButton_bcolor_map_clicked();
+
 public slots:
 	void accept();
 
 private:
 	Options *_options;
 	QColor _baseColor;
+	QColor _backgroundColor;
+	QColor _waypointColor;
+	QColor _poiColor;
 	Ui::optDialog *ui;
 
 };
