@@ -16,6 +16,5 @@ QDebug operator<<(QDebug dbg, const PathPoint &point)
 {
 	dbg.nospace() << "PathPoint(" << point.distance() << ", "
 	  << point.coordinates() << ")";
-
-	return dbg.maybeSpace();
+	return dbg.space();
 }
