@@ -8,26 +8,27 @@
 class TCXParser : public Parser
 {
 public:
-	TCXParser(QList<TrackData> &tracks, QList<RouteData> &routes,
-	  QList<Waypoint> &waypoints) : Parser(tracks, routes, waypoints) {}
 	~TCXParser() {}
 
-	bool loadFile(QFile *file);
+	bool parse(QFile *file, QList<TrackData> &tracks,
+	  QList<RouteData> &routes, QList<Waypoint> &waypoints);
 	QString errorString() const {return _reader.errorString();}
 	int errorLine() const {return _reader.lineNumber();}
 
 private:
-	bool parse();
-	void tcx();
-	void courses();
-	void activities();
-	void course(TrackData &track);
+	void tcx(QList<TrackData> &tracks, QList<Waypoint> &waypoints);
+	void courses(QList<TrackData> &tracks, QList<Waypoint> &waypoints);
+	void activities(QList<TrackData> &tracks);
+	void multiSportSession(QList<TrackData> &tracks);
+	void sport(QList<TrackData> &tracks);
+	void course(QList<Waypoint> &waypoints, TrackData &track);
 	void activity(TrackData &track);
 	void lap(TrackData &track);
 	void trackpoints(TrackData &track);
 	void trackpointData(Trackpoint &trackpoint);
 	void waypointData(Waypoint &waypoint);
 	void extensions(Trackpoint &trackpoint);
+	void heartRateBpm(Trackpoint &trackpoint);
 	Coordinates position();
 	qreal number();
 	QDateTime time();
