@@ -1,12 +1,14 @@
 #include "ellipsoid.h"
 #include "utm.h"
 
-UTM::UTM(int zone) : _tm(Ellipsoid(), (qAbs(zone) - 1)*6 - 180 + 3, 0.9996,
-  500000, zone < 0 ? 10000000 : 0)
+UTM::UTM(const Ellipsoid &ellipsoid, int zone)
+  : _tm(ellipsoid, 0, (qAbs(zone) - 1)*6 - 180 + 3, 0.9996, 500000,
+  zone < 0 ? 10000000 : 0)
 {
 }
 
-UTM::UTM(const Coordinates &c) : _tm(Ellipsoid(), 0, 0, 0, 0)
+UTM::UTM(const Ellipsoid &ellipsoid, const Coordinates &c)
+  : _tm(ellipsoid, 0, 0, 0, 0, 0)
 {
 	int zone = int((c.lon() + 180)/6) + 1;
 
@@ -24,6 +26,6 @@ UTM::UTM(const Coordinates &c) : _tm(Ellipsoid(), 0, 0, 0, 0)
 	}
 	double cm = (zone - 1)*6 - 180 + 3;
 
-	_tm = TransverseMercator(Ellipsoid(), cm, 0.9996, 500000,
+	_tm = TransverseMercator(ellipsoid, 0, cm, 0.9996, 500000,
 	  (c.lat() < 0) ? 10000000 : 0);
 }
