@@ -4,6 +4,5 @@ QDebug operator<<(QDebug dbg, const Waypoint &waypoint)
 {
 	dbg.nospace() << "Waypoint(" << waypoint.coordinates() << ", "
 	  << waypoint.name() << ", " << waypoint.description() << ")";
-
-	return dbg.maybeSpace();
+	return dbg.space();
 }
